pub struct BayesOptReport {
pub x: Array1<f64>,
pub fun: f64,
pub success: bool,
pub message: String,
pub nfev: usize,
pub nit: usize,
pub posterior_std: f64,
}Expand description
Result of a bayesian_optimization run.
Fields
x: Array1<f64>Best parameter vector found.
fun: f64Objective value at Self::x.
success: boolWhether the run stopped by callback, target uncertainty, or budget after at least one surrogate-guided iteration.
message: StringHuman-readable termination message.
nfev: usizeObjective evaluations consumed.
nit: usizeBO batches completed after the initial design.
posterior_std: f64Largest posterior standard deviation seen in the final candidate pool.