pub struct ExternalArchive { /* private fields */ }Expand description
External archive storing discarded solutions
Implementations
Sourceimpl ExternalArchive
impl ExternalArchive
Sourcepub fn with_population_size(np: usize, arc_rate: f64) -> Self
pub fn with_population_size(np: usize, arc_rate: f64) -> Self
Create archive with size proportional to population
Sourcepub fn add(&mut self, solution: Array1<f64>)
pub fn add(&mut self, solution: Array1<f64>)
Add a solution to the archive If archive is full, removes a random solution
Sourcepub fn random_select<R: Rng + ?Sized>(
&self,
rng: &mut R,
) -> Option<&Array1<f64>>
pub fn random_select<R: Rng + ?Sized>( &self, rng: &mut R, ) -> Option<&Array1<f64>>
Select a random solution from the archive Returns None if archive is empty
Sourcepub fn random_index<R: Rng + ?Sized>(&self, rng: &mut R) -> Option<usize>
pub fn random_index<R: Rng + ?Sized>(&self, rng: &mut R) -> Option<usize>
Get a random index for archive selection Returns None if archive is empty, otherwise returns a valid index into the archive