OptimizationRecorder

Struct OptimizationRecorder 

pub struct OptimizationRecorder { /* private fields */ }
Records optimization progress for every function evaluation

Implementations

Source

impl OptimizationRecorder

pub fn new(function_name: String) -> Self

Create a new optimization recorder for the given function Uses the default records directory under AUTOEQ_DIR/data_generated/records

pub fn with_output_dir(function_name: String, output_dir: String) -> Self

Create a new optimization recorder with custom output directory

pub fn record_evaluation(&self, x: &Array1<f64>, f_value: f64)

Record a single function evaluation

pub fn set_generation(&self, generation: usize)

Set the current generation number

pub fn create_callback( &self, ) -> Box<dyn FnMut(&DEIntermediate) -> CallbackAction + Send>

Create a callback function that updates generation number

pub fn finalize(&self) -> Result<Vec<String>, Box<dyn Error>>

Save any remaining records and finalize

pub fn get_stats(&self) -> (usize, Option<f64>, usize)

Get evaluation statistics

pub fn save_to_csv(&self, output_dir: &str) -> Result<String, Box<dyn Error>>

Legacy method: Save all recorded iterations to a CSV file (for compatibility)

pub fn get_records(&self) -> Vec<OptimizationRecord>

Get a copy of all recorded iterations (legacy compatibility - returns empty)

pub fn num_iterations(&self) -> usize

Get the number of evaluations recorded

pub fn clear(&self)

Clear all recorded evaluations

pub fn get_best_solution(&self) -> Option<(Vec<f64>, f64)>

Get the final best solution if any evaluations were recorded