pub struct OptimizationRecorder { /* private fields */ }Expand description
Records optimization progress for every function evaluation
Implementations
Sourceimpl OptimizationRecorder
impl OptimizationRecorder
Sourcepub fn new(function_name: String) -> Self
pub fn new(function_name: String) -> Self
Create a new optimization recorder for the given function Uses the default records directory under AUTOEQ_DIR/data_generated/records
Sourcepub fn with_output_dir(function_name: String, output_dir: String) -> Self
pub fn with_output_dir(function_name: String, output_dir: String) -> Self
Create a new optimization recorder with custom output directory
Sourcepub fn record_evaluation(&self, x: &Array1<f64>, f_value: f64)
pub fn record_evaluation(&self, x: &Array1<f64>, f_value: f64)
Record a single function evaluation
Sourcepub fn set_generation(&self, generation: usize)
pub fn set_generation(&self, generation: usize)
Set the current generation number
Sourcepub fn create_callback(
&self,
) -> Box<dyn FnMut(&DEIntermediate) -> CallbackAction + Send>
pub fn create_callback( &self, ) -> Box<dyn FnMut(&DEIntermediate) -> CallbackAction + Send>
Create a callback function that updates generation number
Sourcepub fn finalize(&self) -> Result<Vec<String>, Box<dyn Error>>
pub fn finalize(&self) -> Result<Vec<String>, Box<dyn Error>>
Save any remaining records and finalize
Sourcepub fn save_to_csv(&self, output_dir: &str) -> Result<String, Box<dyn Error>>
pub fn save_to_csv(&self, output_dir: &str) -> Result<String, Box<dyn Error>>
Legacy method: Save all recorded iterations to a CSV file (for compatibility)
Sourcepub fn get_records(&self) -> Vec<OptimizationRecord>
pub fn get_records(&self) -> Vec<OptimizationRecord>
Get a copy of all recorded iterations (legacy compatibility - returns empty)
Sourcepub fn num_iterations(&self) -> usize
pub fn num_iterations(&self) -> usize
Get the number of evaluations recorded